<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// M
	'mots_description' => 'Ŝlosilvortoj kaj grupoj de ŝlosilvortoj',
	'mots_slogan' => 'Mastrumado de ŝlosilvortoj kaj grupoj de ŝlosilvortoj en SPIP',
];
